#[non_exhaustive]pub struct PhaseConfig {
pub phase_id: String,
pub percentage: i32,
pub profiles: Vec<String>,
pub verify: bool,
pub predeploy: Option<Predeploy>,
pub postdeploy: Option<Postdeploy>,
/* private fields */
}Expand description
PhaseConfig represents the configuration for a phase in the custom canary deployment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.phase_id: StringRequired. The ID to assign to the Rollout phase.
This value must consist of lower-case letters, numbers, and hyphens,
start with a letter and end with a letter or a number, and have a max
length of 63 characters. In other words, it must match the following
regex: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$.
percentage: i32Required. Percentage deployment for the phase.
profiles: Vec<String>Optional. Skaffold profiles to use when rendering the manifest for this
phase. These are in addition to the profiles list specified in the
DeliveryPipeline stage.
verify: boolOptional. Whether to run verify tests after the deployment via skaffold verify.
predeploy: Option<Predeploy>Optional. Configuration for the predeploy job of this phase. If this is not configured, there will be no predeploy job for this phase.
postdeploy: Option<Postdeploy>Optional. Configuration for the postdeploy job of this phase. If this is not configured, there will be no postdeploy job for this phase.
Implementations
Sourceimpl PhaseConfig
impl PhaseConfig
Sourcepub fn set_phase_id<T: Into<String>>(self, v: T) -> Self
pub fn set_phase_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_percentage<T: Into<i32>>(self, v: T) -> Self
pub fn set_percentage<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_profiles<T, V>(self, v: T) -> Self
pub fn set_profiles<T, V>(self, v: T) -> Self
Sourcepub fn set_verify<T: Into<bool>>(self, v: T) -> Self
pub fn set_verify<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_predeploy<T>(self, v: T) -> Self
pub fn set_predeploy<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_predeploy<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_predeploy<T>(self, v: Option<T>) -> Self
Sourcepub fn set_postdeploy<T>(self, v: T) -> Selfwhere
T: Into<Postdeploy>,
pub fn set_postdeploy<T>(self, v: T) -> Selfwhere
T: Into<Postdeploy>,
Sets the value of postdeploy.
Example
use google_cloud_deploy_v1::model::Postdeploy;
let x = PhaseConfig::new().set_postdeploy(Postdeploy::default()/* use setters */);Sourcepub fn set_or_clear_postdeploy<T>(self, v: Option<T>) -> Selfwhere
T: Into<Postdeploy>,
pub fn set_or_clear_postdeploy<T>(self, v: Option<T>) -> Selfwhere
T: Into<Postdeploy>,
Sets or clears the value of postdeploy.
Example
use google_cloud_deploy_v1::model::Postdeploy;
let x = PhaseConfig::new().set_or_clear_postdeploy(Some(Postdeploy::default()/* use setters */));
let x = PhaseConfig::new().set_or_clear_postdeploy(None::<Postdeploy>);Trait Implementations
Sourceimpl Clone for PhaseConfig
impl Clone for PhaseConfig
Sourcefn clone(&self) -> PhaseConfig
fn clone(&self) -> PhaseConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PhaseConfig
impl Debug for PhaseConfig
Sourceimpl Default for PhaseConfig
impl Default for PhaseConfig
Sourcefn default() -> PhaseConfig
fn default() -> PhaseConfig
Sourceimpl Message for PhaseConfig
impl Message for PhaseConfig
Sourceimpl PartialEq for PhaseConfig
impl PartialEq for PhaseConfig
impl StructuralPartialEq for PhaseConfig