#[non_exhaustive]pub struct GatewayServiceMesh {
pub http_route: String,
pub service: String,
pub deployment: String,
pub route_update_wait_time: Option<Duration>,
pub stable_cutback_duration: Option<Duration>,
pub pod_selector_label: String,
pub route_destinations: Option<RouteDestinations>,
/* private fields */
}Expand description
Information about the Kubernetes Gateway API service mesh configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.http_route: StringRequired. Name of the Gateway API HTTPRoute.
service: StringRequired. Name of the Kubernetes Service.
deployment: StringRequired. Name of the Kubernetes Deployment whose traffic is managed by the specified HTTPRoute and Service.
route_update_wait_time: Option<Duration>Optional. The time to wait for route updates to propagate. The maximum configurable time is 3 hours, in seconds format. If unspecified, there is no wait time.
stable_cutback_duration: Option<Duration>Optional. The amount of time to migrate traffic back from the canary Service to the original Service during the stable phase deployment. If specified, must be between 15s and 3600s. If unspecified, there is no cutback time.
pod_selector_label: StringOptional. The label to use when selecting Pods for the Deployment and Service resources. This label must already be present in both resources.
route_destinations: Option<RouteDestinations>Optional. Route destinations allow configuring the Gateway API HTTPRoute to be deployed to additional clusters. This option is available for multi-cluster service mesh set ups that require the route to exist in the clusters that call the service. If unspecified, the HTTPRoute will only be deployed to the Target cluster.
Implementations
Sourceimpl GatewayServiceMesh
impl GatewayServiceMesh
Sourcepub fn set_http_route<T: Into<String>>(self, v: T) -> Self
pub fn set_http_route<T: Into<String>>(self, v: T) -> Self
Sets the value of http_route.
Example
let x = GatewayServiceMesh::new().set_http_route("example");Sourcepub fn set_service<T: Into<String>>(self, v: T) -> Self
pub fn set_service<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_deployment<T: Into<String>>(self, v: T) -> Self
pub fn set_deployment<T: Into<String>>(self, v: T) -> Self
Sets the value of deployment.
Example
let x = GatewayServiceMesh::new().set_deployment("example");Sourcepub fn set_route_update_wait_time<T>(self, v: T) -> Self
pub fn set_route_update_wait_time<T>(self, v: T) -> Self
Sets the value of route_update_wait_time.
Example
use wkt::Duration;
let x = GatewayServiceMesh::new().set_route_update_wait_time(Duration::default()/* use setters */);Sourcepub fn set_or_clear_route_update_wait_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_route_update_wait_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of route_update_wait_time.
Example
use wkt::Duration;
let x = GatewayServiceMesh::new().set_or_clear_route_update_wait_time(Some(Duration::default()/* use setters */));
let x = GatewayServiceMesh::new().set_or_clear_route_update_wait_time(None::<Duration>);Sourcepub fn set_stable_cutback_duration<T>(self, v: T) -> Self
pub fn set_stable_cutback_duration<T>(self, v: T) -> Self
Sets the value of stable_cutback_duration.
Example
use wkt::Duration;
let x = GatewayServiceMesh::new().set_stable_cutback_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_stable_cutback_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_stable_cutback_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of stable_cutback_duration.
Example
use wkt::Duration;
let x = GatewayServiceMesh::new().set_or_clear_stable_cutback_duration(Some(Duration::default()/* use setters */));
let x = GatewayServiceMesh::new().set_or_clear_stable_cutback_duration(None::<Duration>);Sourcepub fn set_pod_selector_label<T: Into<String>>(self, v: T) -> Self
pub fn set_pod_selector_label<T: Into<String>>(self, v: T) -> Self
Sets the value of pod_selector_label.
Example
let x = GatewayServiceMesh::new().set_pod_selector_label("example");Sourcepub fn set_route_destinations<T>(self, v: T) -> Selfwhere
T: Into<RouteDestinations>,
pub fn set_route_destinations<T>(self, v: T) -> Selfwhere
T: Into<RouteDestinations>,
Sets the value of route_destinations.
Example
use google_cloud_deploy_v1::model::kubernetes_config::gateway_service_mesh::RouteDestinations;
let x = GatewayServiceMesh::new().set_route_destinations(RouteDestinations::default()/* use setters */);Sourcepub fn set_or_clear_route_destinations<T>(self, v: Option<T>) -> Selfwhere
T: Into<RouteDestinations>,
pub fn set_or_clear_route_destinations<T>(self, v: Option<T>) -> Selfwhere
T: Into<RouteDestinations>,
Sets or clears the value of route_destinations.
Example
use google_cloud_deploy_v1::model::kubernetes_config::gateway_service_mesh::RouteDestinations;
let x = GatewayServiceMesh::new().set_or_clear_route_destinations(Some(RouteDestinations::default()/* use setters */));
let x = GatewayServiceMesh::new().set_or_clear_route_destinations(None::<RouteDestinations>);Trait Implementations
Sourceimpl Clone for GatewayServiceMesh
impl Clone for GatewayServiceMesh
Sourcefn clone(&self) -> GatewayServiceMesh
fn clone(&self) -> GatewayServiceMesh
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GatewayServiceMesh
impl Debug for GatewayServiceMesh
Sourceimpl Default for GatewayServiceMesh
impl Default for GatewayServiceMesh
Sourcefn default() -> GatewayServiceMesh
fn default() -> GatewayServiceMesh
Sourceimpl Message for GatewayServiceMesh
impl Message for GatewayServiceMesh
Sourceimpl PartialEq for GatewayServiceMesh
impl PartialEq for GatewayServiceMesh
impl StructuralPartialEq for GatewayServiceMesh