#[non_exhaustive]pub struct AdvanceRolloutRule {
pub id: String,
pub source_phases: Vec<String>,
pub wait: Option<Duration>,
pub condition: Option<AutomationRuleCondition>,
/* private fields */
}Expand description
The AdvanceRollout automation rule will automatically advance a successful
Rollout to the next phase.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringRequired. ID of the rule. This id must be unique in the Automation
resource to which this rule belongs. The format is
[a-z]([a-z0-9-]{0,61}[a-z0-9])?.
source_phases: Vec<String>Optional. Proceeds only after phase name matched any one in the list.
This value must consist of lower-case letters, numbers, and hyphens,
start with a letter and end with a letter or a number, and have a max
length of 63 characters. In other words, it must match the following
regex: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$.
wait: Option<Duration>Optional. How long to wait after a rollout is finished.
condition: Option<AutomationRuleCondition>Output only. Information around the state of the Automation rule.
Implementations
Sourceimpl AdvanceRolloutRule
impl AdvanceRolloutRule
Sourcepub fn set_source_phases<T, V>(self, v: T) -> Self
pub fn set_source_phases<T, V>(self, v: T) -> Self
Sets the value of source_phases.
Example
let x = AdvanceRolloutRule::new().set_source_phases(["a", "b", "c"]);Sourcepub fn set_or_clear_wait<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_wait<T>(self, v: Option<T>) -> Self
Sourcepub fn set_condition<T>(self, v: T) -> Selfwhere
T: Into<AutomationRuleCondition>,
pub fn set_condition<T>(self, v: T) -> Selfwhere
T: Into<AutomationRuleCondition>,
Sourcepub fn set_or_clear_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<AutomationRuleCondition>,
pub fn set_or_clear_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<AutomationRuleCondition>,
Sets or clears the value of condition.
Example
use google_cloud_deploy_v1::model::AutomationRuleCondition;
let x = AdvanceRolloutRule::new().set_or_clear_condition(Some(AutomationRuleCondition::default()/* use setters */));
let x = AdvanceRolloutRule::new().set_or_clear_condition(None::<AutomationRuleCondition>);Trait Implementations
Sourceimpl Clone for AdvanceRolloutRule
impl Clone for AdvanceRolloutRule
Sourcefn clone(&self) -> AdvanceRolloutRule
fn clone(&self) -> AdvanceRolloutRule
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AdvanceRolloutRule
impl Debug for AdvanceRolloutRule
Sourceimpl Default for AdvanceRolloutRule
impl Default for AdvanceRolloutRule
Sourcefn default() -> AdvanceRolloutRule
fn default() -> AdvanceRolloutRule
Sourceimpl Message for AdvanceRolloutRule
impl Message for AdvanceRolloutRule
Sourceimpl PartialEq for AdvanceRolloutRule
impl PartialEq for AdvanceRolloutRule
impl StructuralPartialEq for AdvanceRolloutRule