#[non_exhaustive]pub struct CanaryDeployment {
pub percentages: Vec<i32>,
pub verify: bool,
pub predeploy: Option<Predeploy>,
pub postdeploy: Option<Postdeploy>,
/* private fields */
}Expand description
CanaryDeployment represents the canary deployment configuration
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.percentages: Vec<i32>Required. The percentage based deployments that will occur as a part of a
Rollout. List is expected in ascending order and each integer n is
0 <= n < 100.
If the GatewayServiceMesh is configured for Kubernetes, then the range for
n is 0 <= n <= 100.
verify: boolOptional. Whether to run verify tests after each percentage deployment via
skaffold verify.
predeploy: Option<Predeploy>Optional. Configuration for the predeploy job of the first phase. If this is not configured, there will be no predeploy job for this phase.
postdeploy: Option<Postdeploy>Optional. Configuration for the postdeploy job of the last phase. If this is not configured, there will be no postdeploy job for this phase.
Implementations
Sourceimpl CanaryDeployment
impl CanaryDeployment
Sourcepub fn set_percentages<T, V>(self, v: T) -> Self
pub fn set_percentages<T, V>(self, v: T) -> Self
Sets the value of percentages.
Example
let x = CanaryDeployment::new().set_percentages([1, 2, 3]);Sourcepub fn set_verify<T: Into<bool>>(self, v: T) -> Self
pub fn set_verify<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_predeploy<T>(self, v: T) -> Self
pub fn set_predeploy<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_predeploy<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_predeploy<T>(self, v: Option<T>) -> Self
Sourcepub fn set_postdeploy<T>(self, v: T) -> Selfwhere
T: Into<Postdeploy>,
pub fn set_postdeploy<T>(self, v: T) -> Selfwhere
T: Into<Postdeploy>,
Sets the value of postdeploy.
Example
use google_cloud_deploy_v1::model::Postdeploy;
let x = CanaryDeployment::new().set_postdeploy(Postdeploy::default()/* use setters */);Sourcepub fn set_or_clear_postdeploy<T>(self, v: Option<T>) -> Selfwhere
T: Into<Postdeploy>,
pub fn set_or_clear_postdeploy<T>(self, v: Option<T>) -> Selfwhere
T: Into<Postdeploy>,
Sets or clears the value of postdeploy.
Example
use google_cloud_deploy_v1::model::Postdeploy;
let x = CanaryDeployment::new().set_or_clear_postdeploy(Some(Postdeploy::default()/* use setters */));
let x = CanaryDeployment::new().set_or_clear_postdeploy(None::<Postdeploy>);Trait Implementations
Sourceimpl Clone for CanaryDeployment
impl Clone for CanaryDeployment
Sourcefn clone(&self) -> CanaryDeployment
fn clone(&self) -> CanaryDeployment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CanaryDeployment
impl Debug for CanaryDeployment
Sourceimpl Default for CanaryDeployment
impl Default for CanaryDeployment
Sourcefn default() -> CanaryDeployment
fn default() -> CanaryDeployment
Sourceimpl Message for CanaryDeployment
impl Message for CanaryDeployment
Sourceimpl PartialEq for CanaryDeployment
impl PartialEq for CanaryDeployment
impl StructuralPartialEq for CanaryDeployment