#[non_exhaustive]pub struct CloudRunConfig {
pub automatic_traffic_control: bool,
pub canary_revision_tags: Vec<String>,
pub prior_revision_tags: Vec<String>,
pub stable_revision_tags: Vec<String>,
/* private fields */
}Expand description
CloudRunConfig contains the Cloud Run runtime configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.automatic_traffic_control: boolOptional. Whether Cloud Deploy should update the traffic stanza in a Cloud Run Service on the user’s behalf to facilitate traffic splitting. This is required to be true for CanaryDeployments, but optional for CustomCanaryDeployments.
Optional. A list of tags that are added to the canary revision while the canary phase is in progress.
Optional. A list of tags that are added to the prior revision while the canary phase is in progress.
Optional. A list of tags that are added to the final stable revision when the stable phase is applied.
Implementations
Sourceimpl CloudRunConfig
impl CloudRunConfig
Sourcepub fn set_automatic_traffic_control<T: Into<bool>>(self, v: T) -> Self
pub fn set_automatic_traffic_control<T: Into<bool>>(self, v: T) -> Self
Sets the value of automatic_traffic_control.
Example
let x = CloudRunConfig::new().set_automatic_traffic_control(true);Sets the value of canary_revision_tags.
Example
let x = CloudRunConfig::new().set_canary_revision_tags(["a", "b", "c"]);Sets the value of prior_revision_tags.
Example
let x = CloudRunConfig::new().set_prior_revision_tags(["a", "b", "c"]);Sets the value of stable_revision_tags.
Example
let x = CloudRunConfig::new().set_stable_revision_tags(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for CloudRunConfig
impl Clone for CloudRunConfig
Sourcefn clone(&self) -> CloudRunConfig
fn clone(&self) -> CloudRunConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CloudRunConfig
impl Debug for CloudRunConfig
Sourceimpl Default for CloudRunConfig
impl Default for CloudRunConfig
Sourcefn default() -> CloudRunConfig
fn default() -> CloudRunConfig
Sourceimpl Message for CloudRunConfig
impl Message for CloudRunConfig
Sourceimpl PartialEq for CloudRunConfig
impl PartialEq for CloudRunConfig
impl StructuralPartialEq for CloudRunConfig