#[non_exhaustive]pub struct CreateCustomTargetTypeRequest {
pub parent: String,
pub custom_target_type_id: String,
pub custom_target_type: Option<CustomTargetType>,
pub request_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
The request object for CreateCustomTargetType.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent collection in which the CustomTargetType must be
created. The format is projects/{project_id}/locations/{location_name}.
custom_target_type_id: StringRequired. ID of the CustomTargetType.
custom_target_type: Option<CustomTargetType>Required. The CustomTargetType to create.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. If set to true, the request is validated and the user is provided with an expected result, but no actual change is made.
Implementations
Sourceimpl CreateCustomTargetTypeRequest
impl CreateCustomTargetTypeRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_custom_target_type_id<T: Into<String>>(self, v: T) -> Self
pub fn set_custom_target_type_id<T: Into<String>>(self, v: T) -> Self
Sets the value of custom_target_type_id.
Example
let x = CreateCustomTargetTypeRequest::new().set_custom_target_type_id("example");Sourcepub fn set_custom_target_type<T>(self, v: T) -> Selfwhere
T: Into<CustomTargetType>,
pub fn set_custom_target_type<T>(self, v: T) -> Selfwhere
T: Into<CustomTargetType>,
Sets the value of custom_target_type.
Example
use google_cloud_deploy_v1::model::CustomTargetType;
let x = CreateCustomTargetTypeRequest::new().set_custom_target_type(CustomTargetType::default()/* use setters */);Sourcepub fn set_or_clear_custom_target_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<CustomTargetType>,
pub fn set_or_clear_custom_target_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<CustomTargetType>,
Sets or clears the value of custom_target_type.
Example
use google_cloud_deploy_v1::model::CustomTargetType;
let x = CreateCustomTargetTypeRequest::new().set_or_clear_custom_target_type(Some(CustomTargetType::default()/* use setters */));
let x = CreateCustomTargetTypeRequest::new().set_or_clear_custom_target_type(None::<CustomTargetType>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateCustomTargetTypeRequest::new().set_request_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateCustomTargetTypeRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateCustomTargetTypeRequest
impl Clone for CreateCustomTargetTypeRequest
Sourcefn clone(&self) -> CreateCustomTargetTypeRequest
fn clone(&self) -> CreateCustomTargetTypeRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateCustomTargetTypeRequest
impl Default for CreateCustomTargetTypeRequest
Sourcefn default() -> CreateCustomTargetTypeRequest
fn default() -> CreateCustomTargetTypeRequest
impl StructuralPartialEq for CreateCustomTargetTypeRequest