#[non_exhaustive]pub struct DeleteDeliveryPipelineRequest {
pub name: String,
pub request_id: String,
pub allow_missing: bool,
pub validate_only: bool,
pub force: bool,
pub etag: String,
/* private fields */
}Expand description
The request object for DeleteDeliveryPipeline.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the DeliveryPipeline to delete. The format is
projects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
allow_missing: boolOptional. If set to true, then deleting an already deleted or non-existing
DeliveryPipeline will succeed.
validate_only: boolOptional. If set, validate the request and preview the review, but do not actually post it.
force: boolOptional. If set to true, all child resources under this pipeline will also be deleted. Otherwise, the request will only work if the pipeline has no child resources.
etag: StringOptional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
Implementations
Sourceimpl DeleteDeliveryPipelineRequest
impl DeleteDeliveryPipelineRequest
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = DeleteDeliveryPipelineRequest::new().set_request_id("example");Sourcepub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self
Sets the value of allow_missing.
Example
let x = DeleteDeliveryPipelineRequest::new().set_allow_missing(true);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = DeleteDeliveryPipelineRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for DeleteDeliveryPipelineRequest
impl Clone for DeleteDeliveryPipelineRequest
Sourcefn clone(&self) -> DeleteDeliveryPipelineRequest
fn clone(&self) -> DeleteDeliveryPipelineRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for DeleteDeliveryPipelineRequest
impl Default for DeleteDeliveryPipelineRequest
Sourcefn default() -> DeleteDeliveryPipelineRequest
fn default() -> DeleteDeliveryPipelineRequest
impl StructuralPartialEq for DeleteDeliveryPipelineRequest