#[non_exhaustive]pub struct DeliveryPipeline {
pub name: String,
pub uid: String,
pub description: String,
pub annotations: HashMap<String, String>,
pub labels: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub condition: Option<PipelineCondition>,
pub etag: String,
pub suspended: bool,
pub pipeline: Option<Pipeline>,
/* private fields */
}Expand description
A DeliveryPipeline resource in the Cloud Deploy API.
A DeliveryPipeline defines a pipeline through which a Skaffold
configuration can progress.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Name of the DeliveryPipeline. Format is
projects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}.
The deliveryPipeline component must match
[a-z]([a-z0-9-]{0,61}[a-z0-9])?
uid: StringOutput only. Unique identifier of the DeliveryPipeline.
description: StringOptional. Description of the DeliveryPipeline. Max length is 255
characters.
annotations: HashMap<String, String>Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy.
labels: HashMap<String, String>Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints:
- Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes.
- All characters must use UTF-8 encoding, and international characters are allowed.
- Keys must start with a lowercase letter or international character.
- Each resource is limited to a maximum of 64 labels.
Both keys and values are additionally constrained to be <= 128 bytes.
create_time: Option<Timestamp>Output only. Time at which the pipeline was created.
update_time: Option<Timestamp>Output only. Most recent time at which the pipeline was updated.
condition: Option<PipelineCondition>Output only. Information around the state of the Delivery Pipeline.
etag: StringThis checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
suspended: boolOptional. When suspended, no new releases or rollouts can be created, but in-progress ones will complete.
pipeline: Option<Pipeline>The ordering configuration of the DeliveryPipeline.
Implementations
Sourceimpl DeliveryPipeline
impl DeliveryPipeline
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = DeliveryPipeline::new().set_description("example");Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = DeliveryPipeline::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DeliveryPipeline::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DeliveryPipeline::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DeliveryPipeline::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DeliveryPipeline::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DeliveryPipeline::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DeliveryPipeline::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_condition<T>(self, v: T) -> Selfwhere
T: Into<PipelineCondition>,
pub fn set_condition<T>(self, v: T) -> Selfwhere
T: Into<PipelineCondition>,
Sourcepub fn set_or_clear_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<PipelineCondition>,
pub fn set_or_clear_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<PipelineCondition>,
Sourcepub fn set_suspended<T: Into<bool>>(self, v: T) -> Self
pub fn set_suspended<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_pipeline<T: Into<Option<Pipeline>>>(self, v: T) -> Self
pub fn set_pipeline<T: Into<Option<Pipeline>>>(self, v: T) -> Self
Sets the value of pipeline.
Note that all the setters affecting pipeline are mutually
exclusive.
Example
use google_cloud_deploy_v1::model::SerialPipeline;
let x = DeliveryPipeline::new().set_pipeline(Some(
google_cloud_deploy_v1::model::delivery_pipeline::Pipeline::SerialPipeline(SerialPipeline::default().into())));Sourcepub fn serial_pipeline(&self) -> Option<&Box<SerialPipeline>>
pub fn serial_pipeline(&self) -> Option<&Box<SerialPipeline>>
The value of pipeline
if it holds a SerialPipeline, None if the field is not set or
holds a different branch.
Sourcepub fn set_serial_pipeline<T: Into<Box<SerialPipeline>>>(self, v: T) -> Self
pub fn set_serial_pipeline<T: Into<Box<SerialPipeline>>>(self, v: T) -> Self
Sets the value of pipeline
to hold a SerialPipeline.
Note that all the setters affecting pipeline are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::SerialPipeline;
let x = DeliveryPipeline::new().set_serial_pipeline(SerialPipeline::default()/* use setters */);
assert!(x.serial_pipeline().is_some());Trait Implementations
Sourceimpl Clone for DeliveryPipeline
impl Clone for DeliveryPipeline
Sourcefn clone(&self) -> DeliveryPipeline
fn clone(&self) -> DeliveryPipeline
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DeliveryPipeline
impl Debug for DeliveryPipeline
Sourceimpl Default for DeliveryPipeline
impl Default for DeliveryPipeline
Sourcefn default() -> DeliveryPipeline
fn default() -> DeliveryPipeline
Sourceimpl Message for DeliveryPipeline
impl Message for DeliveryPipeline
Sourceimpl PartialEq for DeliveryPipeline
impl PartialEq for DeliveryPipeline
impl StructuralPartialEq for DeliveryPipeline