#[non_exhaustive]pub struct DeployPolicyEvaluationEvent {Show 13 fields
pub message: String,
pub rule_type: String,
pub rule: String,
pub pipeline_uid: String,
pub delivery_pipeline: String,
pub target_uid: String,
pub target: String,
pub invoker: Invoker,
pub deploy_policy: String,
pub deploy_policy_uid: String,
pub allowed: bool,
pub verdict: PolicyVerdict,
pub overrides: Vec<PolicyVerdictOverride>,
/* private fields */
}Expand description
Payload proto for “clouddeploy.googleapis.com/deploypolicy_evaluation” Platform Log event that describes the deploy policy evaluation event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: StringDebug message for when a deploy policy event occurs.
rule_type: StringRule type (e.g. Restrict Rollouts).
rule: StringRule id.
pipeline_uid: StringUnique identifier of the Delivery Pipeline.
delivery_pipeline: StringThe name of the Delivery Pipeline.
target_uid: StringUnique identifier of the Target. This is an optional field, as a Target
may not always be applicable to a policy.
target: StringThe name of the Target. This is an optional field, as a Target may not
always be applicable to a policy.
invoker: InvokerWhat invoked the action (e.g. a user or automation).
deploy_policy: StringThe name of the DeployPolicy.
deploy_policy_uid: StringUnique identifier of the DeployPolicy.
allowed: boolWhether the request is allowed. Allowed is set as true if: (1) the request complies with the policy; or (2) the request doesn’t comply with the policy but the policy was overridden; or (3) the request doesn’t comply with the policy but the policy was suspended
verdict: PolicyVerdictThe policy verdict of the request.
overrides: Vec<PolicyVerdictOverride>Things that could have overridden the policy verdict. Overrides together with verdict decide whether the request is allowed.
Implementations
Sourceimpl DeployPolicyEvaluationEvent
impl DeployPolicyEvaluationEvent
Sourcepub fn set_message<T: Into<String>>(self, v: T) -> Self
pub fn set_message<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_rule_type<T: Into<String>>(self, v: T) -> Self
pub fn set_rule_type<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_pipeline_uid<T: Into<String>>(self, v: T) -> Self
pub fn set_pipeline_uid<T: Into<String>>(self, v: T) -> Self
Sets the value of pipeline_uid.
Example
let x = DeployPolicyEvaluationEvent::new().set_pipeline_uid("example");Sourcepub fn set_delivery_pipeline<T: Into<String>>(self, v: T) -> Self
pub fn set_delivery_pipeline<T: Into<String>>(self, v: T) -> Self
Sets the value of delivery_pipeline.
Example
let x = DeployPolicyEvaluationEvent::new().set_delivery_pipeline("example");Sourcepub fn set_target_uid<T: Into<String>>(self, v: T) -> Self
pub fn set_target_uid<T: Into<String>>(self, v: T) -> Self
Sets the value of target_uid.
Example
let x = DeployPolicyEvaluationEvent::new().set_target_uid("example");Sourcepub fn set_target<T: Into<String>>(self, v: T) -> Self
pub fn set_target<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_invoker<T: Into<Invoker>>(self, v: T) -> Self
pub fn set_invoker<T: Into<Invoker>>(self, v: T) -> Self
Sourcepub fn set_deploy_policy<T: Into<String>>(self, v: T) -> Self
pub fn set_deploy_policy<T: Into<String>>(self, v: T) -> Self
Sets the value of deploy_policy.
Example
let x = DeployPolicyEvaluationEvent::new().set_deploy_policy("example");Sourcepub fn set_deploy_policy_uid<T: Into<String>>(self, v: T) -> Self
pub fn set_deploy_policy_uid<T: Into<String>>(self, v: T) -> Self
Sets the value of deploy_policy_uid.
Example
let x = DeployPolicyEvaluationEvent::new().set_deploy_policy_uid("example");Sourcepub fn set_allowed<T: Into<bool>>(self, v: T) -> Self
pub fn set_allowed<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_verdict<T: Into<PolicyVerdict>>(self, v: T) -> Self
pub fn set_verdict<T: Into<PolicyVerdict>>(self, v: T) -> Self
Sourcepub fn set_overrides<T, V>(self, v: T) -> Self
pub fn set_overrides<T, V>(self, v: T) -> Self