#[non_exhaustive]pub struct Job {
pub id: String,
pub state: State,
pub skip_message: String,
pub job_run: String,
pub job_type: Option<JobType>,
/* private fields */
}Expand description
Job represents an operation for a Rollout.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringOutput only. The ID of the Job.
state: StateOutput only. The current state of the Job.
skip_message: StringOutput only. Additional information on why the Job was skipped, if available.
job_run: StringOutput only. The name of the JobRun responsible for the most recent
invocation of this Job.
job_type: Option<JobType>The type of Job.
Implementations
Sourceimpl Job
impl Job
Sourcepub fn set_skip_message<T: Into<String>>(self, v: T) -> Self
pub fn set_skip_message<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_job_run<T: Into<String>>(self, v: T) -> Self
pub fn set_job_run<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_job_type<T: Into<Option<JobType>>>(self, v: T) -> Self
pub fn set_job_type<T: Into<Option<JobType>>>(self, v: T) -> Self
Sourcepub fn deploy_job(&self) -> Option<&Box<DeployJob>>
pub fn deploy_job(&self) -> Option<&Box<DeployJob>>
The value of job_type
if it holds a DeployJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_deploy_job<T: Into<Box<DeployJob>>>(self, v: T) -> Self
pub fn set_deploy_job<T: Into<Box<DeployJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a DeployJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::DeployJob;
let x = Job::new().set_deploy_job(DeployJob::default()/* use setters */);
assert!(x.deploy_job().is_some());
assert!(x.verify_job().is_none());
assert!(x.predeploy_job().is_none());
assert!(x.postdeploy_job().is_none());
assert!(x.create_child_rollout_job().is_none());
assert!(x.advance_child_rollout_job().is_none());Sourcepub fn verify_job(&self) -> Option<&Box<VerifyJob>>
pub fn verify_job(&self) -> Option<&Box<VerifyJob>>
The value of job_type
if it holds a VerifyJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_verify_job<T: Into<Box<VerifyJob>>>(self, v: T) -> Self
pub fn set_verify_job<T: Into<Box<VerifyJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a VerifyJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::VerifyJob;
let x = Job::new().set_verify_job(VerifyJob::default()/* use setters */);
assert!(x.verify_job().is_some());
assert!(x.deploy_job().is_none());
assert!(x.predeploy_job().is_none());
assert!(x.postdeploy_job().is_none());
assert!(x.create_child_rollout_job().is_none());
assert!(x.advance_child_rollout_job().is_none());Sourcepub fn predeploy_job(&self) -> Option<&Box<PredeployJob>>
pub fn predeploy_job(&self) -> Option<&Box<PredeployJob>>
The value of job_type
if it holds a PredeployJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_predeploy_job<T: Into<Box<PredeployJob>>>(self, v: T) -> Self
pub fn set_predeploy_job<T: Into<Box<PredeployJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a PredeployJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::PredeployJob;
let x = Job::new().set_predeploy_job(PredeployJob::default()/* use setters */);
assert!(x.predeploy_job().is_some());
assert!(x.deploy_job().is_none());
assert!(x.verify_job().is_none());
assert!(x.postdeploy_job().is_none());
assert!(x.create_child_rollout_job().is_none());
assert!(x.advance_child_rollout_job().is_none());Sourcepub fn postdeploy_job(&self) -> Option<&Box<PostdeployJob>>
pub fn postdeploy_job(&self) -> Option<&Box<PostdeployJob>>
The value of job_type
if it holds a PostdeployJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_postdeploy_job<T: Into<Box<PostdeployJob>>>(self, v: T) -> Self
pub fn set_postdeploy_job<T: Into<Box<PostdeployJob>>>(self, v: T) -> Self
Sets the value of job_type
to hold a PostdeployJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::PostdeployJob;
let x = Job::new().set_postdeploy_job(PostdeployJob::default()/* use setters */);
assert!(x.postdeploy_job().is_some());
assert!(x.deploy_job().is_none());
assert!(x.verify_job().is_none());
assert!(x.predeploy_job().is_none());
assert!(x.create_child_rollout_job().is_none());
assert!(x.advance_child_rollout_job().is_none());Sourcepub fn create_child_rollout_job(&self) -> Option<&Box<CreateChildRolloutJob>>
pub fn create_child_rollout_job(&self) -> Option<&Box<CreateChildRolloutJob>>
The value of job_type
if it holds a CreateChildRolloutJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_create_child_rollout_job<T: Into<Box<CreateChildRolloutJob>>>(
self,
v: T,
) -> Self
pub fn set_create_child_rollout_job<T: Into<Box<CreateChildRolloutJob>>>( self, v: T, ) -> Self
Sets the value of job_type
to hold a CreateChildRolloutJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::CreateChildRolloutJob;
let x = Job::new().set_create_child_rollout_job(CreateChildRolloutJob::default()/* use setters */);
assert!(x.create_child_rollout_job().is_some());
assert!(x.deploy_job().is_none());
assert!(x.verify_job().is_none());
assert!(x.predeploy_job().is_none());
assert!(x.postdeploy_job().is_none());
assert!(x.advance_child_rollout_job().is_none());Sourcepub fn advance_child_rollout_job(&self) -> Option<&Box<AdvanceChildRolloutJob>>
pub fn advance_child_rollout_job(&self) -> Option<&Box<AdvanceChildRolloutJob>>
The value of job_type
if it holds a AdvanceChildRolloutJob, None if the field is not set or
holds a different branch.
Sourcepub fn set_advance_child_rollout_job<T: Into<Box<AdvanceChildRolloutJob>>>(
self,
v: T,
) -> Self
pub fn set_advance_child_rollout_job<T: Into<Box<AdvanceChildRolloutJob>>>( self, v: T, ) -> Self
Sets the value of job_type
to hold a AdvanceChildRolloutJob.
Note that all the setters affecting job_type are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::AdvanceChildRolloutJob;
let x = Job::new().set_advance_child_rollout_job(AdvanceChildRolloutJob::default()/* use setters */);
assert!(x.advance_child_rollout_job().is_some());
assert!(x.deploy_job().is_none());
assert!(x.verify_job().is_none());
assert!(x.predeploy_job().is_none());
assert!(x.postdeploy_job().is_none());
assert!(x.create_child_rollout_job().is_none());Trait Implementations
impl StructuralPartialEq for Job