#[non_exhaustive]pub struct ListAutomationRunsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
The request object for ListAutomationRuns.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent Delivery Pipeline, which owns this collection of
automationRuns. Format must be
projects/{project}/locations/{location}/deliveryPipelines/{delivery_pipeline}.
page_size: i32The maximum number of automationRuns to return. The service may return fewer than this value. If unspecified, at most 50 automationRuns will be returned. The maximum value is 1000; values above 1000 will be set to 1000.
page_token: StringA page token, received from a previous ListAutomationRuns call.
Provide this to retrieve the subsequent page.
When paginating, all other provided parameters match the call that provided the page token.
filter: StringFilter automationRuns to be returned. All fields can be used in the filter.
order_by: StringField to sort by.
Implementations
Sourceimpl ListAutomationRunsRequest
impl ListAutomationRunsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListAutomationRunsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self