#[non_exhaustive]pub struct Release {Show 22 fields
pub name: String,
pub uid: String,
pub description: String,
pub annotations: HashMap<String, String>,
pub labels: HashMap<String, String>,
pub abandoned: bool,
pub create_time: Option<Timestamp>,
pub render_start_time: Option<Timestamp>,
pub render_end_time: Option<Timestamp>,
pub skaffold_config_uri: String,
pub skaffold_config_path: String,
pub build_artifacts: Vec<BuildArtifact>,
pub delivery_pipeline_snapshot: Option<DeliveryPipeline>,
pub target_snapshots: Vec<Target>,
pub custom_target_type_snapshots: Vec<CustomTargetType>,
pub render_state: RenderState,
pub etag: String,
pub skaffold_version: String,
pub target_artifacts: HashMap<String, TargetArtifact>,
pub target_renders: HashMap<String, TargetRender>,
pub condition: Option<ReleaseCondition>,
pub deploy_parameters: HashMap<String, String>,
/* private fields */
}Expand description
A Release resource in the Cloud Deploy API.
A Release defines a specific Skaffold configuration instance
that can be deployed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Name of the Release. Format is
projects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}.
The release component must match [a-z]([a-z0-9-]{0,61}[a-z0-9])?
uid: StringOutput only. Unique identifier of the Release.
description: StringOptional. Description of the Release. Max length is 255 characters.
annotations: HashMap<String, String>Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations.
labels: HashMap<String, String>Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints:
- Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes.
- All characters must use UTF-8 encoding, and international characters are allowed.
- Keys must start with a lowercase letter or international character.
- Each resource is limited to a maximum of 64 labels.
Both keys and values are additionally constrained to be <= 128 bytes.
abandoned: boolOutput only. Indicates whether this is an abandoned release.
create_time: Option<Timestamp>Output only. Time at which the Release was created.
render_start_time: Option<Timestamp>Output only. Time at which the render began.
render_end_time: Option<Timestamp>Output only. Time at which the render completed.
skaffold_config_uri: StringOptional. Cloud Storage URI of tar.gz archive containing Skaffold configuration.
skaffold_config_path: StringOptional. Filepath of the Skaffold config inside of the config URI.
build_artifacts: Vec<BuildArtifact>Optional. List of artifacts to pass through to Skaffold command.
delivery_pipeline_snapshot: Option<DeliveryPipeline>Output only. Snapshot of the parent pipeline taken at release creation time.
target_snapshots: Vec<Target>Output only. Snapshot of the targets taken at release creation time.
custom_target_type_snapshots: Vec<CustomTargetType>Output only. Snapshot of the custom target types referenced by the targets taken at release creation time.
render_state: RenderStateOutput only. Current state of the render operation.
etag: StringThis checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
skaffold_version: StringOptional. The Skaffold version to use when operating on this release, such as “1.20.0”. Not all versions are valid; Cloud Deploy supports a specific set of versions.
If unset, the most recent supported Skaffold version will be used.
target_artifacts: HashMap<String, TargetArtifact>Output only. Map from target ID to the target artifacts created during the render operation.
target_renders: HashMap<String, TargetRender>Output only. Map from target ID to details of the render operation for that target.
condition: Option<ReleaseCondition>Output only. Information around the state of the Release.
deploy_parameters: HashMap<String, String>Optional. The deploy parameters to use for all targets in this release.
Implementations
Sourceimpl Release
impl Release
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = Release::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_abandoned<T: Into<bool>>(self, v: T) -> Self
pub fn set_abandoned<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Release::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Release::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Release::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_render_start_time<T>(self, v: T) -> Self
pub fn set_render_start_time<T>(self, v: T) -> Self
Sets the value of render_start_time.
Example
use wkt::Timestamp;
let x = Release::new().set_render_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_render_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_render_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of render_start_time.
Example
use wkt::Timestamp;
let x = Release::new().set_or_clear_render_start_time(Some(Timestamp::default()/* use setters */));
let x = Release::new().set_or_clear_render_start_time(None::<Timestamp>);Sourcepub fn set_render_end_time<T>(self, v: T) -> Self
pub fn set_render_end_time<T>(self, v: T) -> Self
Sets the value of render_end_time.
Example
use wkt::Timestamp;
let x = Release::new().set_render_end_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_render_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_render_end_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of render_end_time.
Example
use wkt::Timestamp;
let x = Release::new().set_or_clear_render_end_time(Some(Timestamp::default()/* use setters */));
let x = Release::new().set_or_clear_render_end_time(None::<Timestamp>);Sourcepub fn set_skaffold_config_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_skaffold_config_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of skaffold_config_uri.
Example
let x = Release::new().set_skaffold_config_uri("example");Sourcepub fn set_skaffold_config_path<T: Into<String>>(self, v: T) -> Self
pub fn set_skaffold_config_path<T: Into<String>>(self, v: T) -> Self
Sets the value of skaffold_config_path.
Example
let x = Release::new().set_skaffold_config_path("example");Sourcepub fn set_build_artifacts<T, V>(self, v: T) -> Self
pub fn set_build_artifacts<T, V>(self, v: T) -> Self
Sets the value of build_artifacts.
Example
use google_cloud_deploy_v1::model::BuildArtifact;
let x = Release::new()
.set_build_artifacts([
BuildArtifact::default()/* use setters */,
BuildArtifact::default()/* use (different) setters */,
]);Sourcepub fn set_delivery_pipeline_snapshot<T>(self, v: T) -> Selfwhere
T: Into<DeliveryPipeline>,
pub fn set_delivery_pipeline_snapshot<T>(self, v: T) -> Selfwhere
T: Into<DeliveryPipeline>,
Sets the value of delivery_pipeline_snapshot.
Example
use google_cloud_deploy_v1::model::DeliveryPipeline;
let x = Release::new().set_delivery_pipeline_snapshot(DeliveryPipeline::default()/* use setters */);Sourcepub fn set_or_clear_delivery_pipeline_snapshot<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeliveryPipeline>,
pub fn set_or_clear_delivery_pipeline_snapshot<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeliveryPipeline>,
Sets or clears the value of delivery_pipeline_snapshot.
Example
use google_cloud_deploy_v1::model::DeliveryPipeline;
let x = Release::new().set_or_clear_delivery_pipeline_snapshot(Some(DeliveryPipeline::default()/* use setters */));
let x = Release::new().set_or_clear_delivery_pipeline_snapshot(None::<DeliveryPipeline>);Sourcepub fn set_target_snapshots<T, V>(self, v: T) -> Self
pub fn set_target_snapshots<T, V>(self, v: T) -> Self
Sets the value of target_snapshots.
Example
use google_cloud_deploy_v1::model::Target;
let x = Release::new()
.set_target_snapshots([
Target::default()/* use setters */,
Target::default()/* use (different) setters */,
]);Sourcepub fn set_custom_target_type_snapshots<T, V>(self, v: T) -> Self
pub fn set_custom_target_type_snapshots<T, V>(self, v: T) -> Self
Sets the value of custom_target_type_snapshots.
Example
use google_cloud_deploy_v1::model::CustomTargetType;
let x = Release::new()
.set_custom_target_type_snapshots([
CustomTargetType::default()/* use setters */,
CustomTargetType::default()/* use (different) setters */,
]);Sourcepub fn set_render_state<T: Into<RenderState>>(self, v: T) -> Self
pub fn set_render_state<T: Into<RenderState>>(self, v: T) -> Self
Sets the value of render_state.
Example
use google_cloud_deploy_v1::model::release::RenderState;
let x0 = Release::new().set_render_state(RenderState::Succeeded);
let x1 = Release::new().set_render_state(RenderState::Failed);
let x2 = Release::new().set_render_state(RenderState::InProgress);Sourcepub fn set_skaffold_version<T: Into<String>>(self, v: T) -> Self
pub fn set_skaffold_version<T: Into<String>>(self, v: T) -> Self
Sets the value of skaffold_version.
Example
let x = Release::new().set_skaffold_version("example");Sourcepub fn set_target_artifacts<T, K, V>(self, v: T) -> Self
pub fn set_target_artifacts<T, K, V>(self, v: T) -> Self
Sets the value of target_artifacts.
Example
use google_cloud_deploy_v1::model::TargetArtifact;
let x = Release::new().set_target_artifacts([
("key0", TargetArtifact::default()/* use setters */),
("key1", TargetArtifact::default()/* use (different) setters */),
]);Sourcepub fn set_target_renders<T, K, V>(self, v: T) -> Self
pub fn set_target_renders<T, K, V>(self, v: T) -> Self
Sets the value of target_renders.
Example
use google_cloud_deploy_v1::model::release::TargetRender;
let x = Release::new().set_target_renders([
("key0", TargetRender::default()/* use setters */),
("key1", TargetRender::default()/* use (different) setters */),
]);Sourcepub fn set_condition<T>(self, v: T) -> Selfwhere
T: Into<ReleaseCondition>,
pub fn set_condition<T>(self, v: T) -> Selfwhere
T: Into<ReleaseCondition>,
Sourcepub fn set_or_clear_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReleaseCondition>,
pub fn set_or_clear_condition<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReleaseCondition>,
Sourcepub fn set_deploy_parameters<T, K, V>(self, v: T) -> Self
pub fn set_deploy_parameters<T, K, V>(self, v: T) -> Self
Sets the value of deploy_parameters.
Example
let x = Release::new().set_deploy_parameters([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
impl StructuralPartialEq for Release