#[non_exhaustive]pub struct RollbackTargetRequest {
pub name: String,
pub target_id: String,
pub rollout_id: String,
pub release_id: String,
pub rollout_to_roll_back: String,
pub rollback_config: Option<RollbackTargetConfig>,
pub validate_only: bool,
pub override_deploy_policy: Vec<String>,
/* private fields */
}Expand description
The request object for RollbackTarget.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The DeliveryPipeline for which the rollback Rollout must be
created. The format is
projects/{project_id}/locations/{location_name}/deliveryPipelines/{pipeline_name}.
target_id: StringRequired. ID of the Target that is being rolled back.
rollout_id: StringRequired. ID of the rollback Rollout to create.
release_id: StringOptional. ID of the Release to roll back to. If this isn’t specified, the
previous successful Rollout to the specified target will be used to
determine the Release.
rollout_to_roll_back: StringOptional. If provided, this must be the latest Rollout that is on the
Target.
rollback_config: Option<RollbackTargetConfig>Optional. Configs for the rollback Rollout.
validate_only: boolOptional. If set to true, the request is validated and the user is provided
with a RollbackTargetResponse.
override_deploy_policy: Vec<String>Optional. Deploy policies to override. Format is
projects/{project}/locations/{location}/deployPolicies/{deploy_policy}.
Implementations
Sourceimpl RollbackTargetRequest
impl RollbackTargetRequest
Sourcepub fn set_target_id<T: Into<String>>(self, v: T) -> Self
pub fn set_target_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_rollout_id<T: Into<String>>(self, v: T) -> Self
pub fn set_rollout_id<T: Into<String>>(self, v: T) -> Self
Sets the value of rollout_id.
Example
let x = RollbackTargetRequest::new().set_rollout_id("example");Sourcepub fn set_release_id<T: Into<String>>(self, v: T) -> Self
pub fn set_release_id<T: Into<String>>(self, v: T) -> Self
Sets the value of release_id.
Example
let x = RollbackTargetRequest::new().set_release_id("example");Sourcepub fn set_rollout_to_roll_back<T: Into<String>>(self, v: T) -> Self
pub fn set_rollout_to_roll_back<T: Into<String>>(self, v: T) -> Self
Sets the value of rollout_to_roll_back.
Example
let x = RollbackTargetRequest::new().set_rollout_to_roll_back("example");Sourcepub fn set_rollback_config<T>(self, v: T) -> Selfwhere
T: Into<RollbackTargetConfig>,
pub fn set_rollback_config<T>(self, v: T) -> Selfwhere
T: Into<RollbackTargetConfig>,
Sets the value of rollback_config.
Example
use google_cloud_deploy_v1::model::RollbackTargetConfig;
let x = RollbackTargetRequest::new().set_rollback_config(RollbackTargetConfig::default()/* use setters */);Sourcepub fn set_or_clear_rollback_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RollbackTargetConfig>,
pub fn set_or_clear_rollback_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RollbackTargetConfig>,
Sets or clears the value of rollback_config.
Example
use google_cloud_deploy_v1::model::RollbackTargetConfig;
let x = RollbackTargetRequest::new().set_or_clear_rollback_config(Some(RollbackTargetConfig::default()/* use setters */));
let x = RollbackTargetRequest::new().set_or_clear_rollback_config(None::<RollbackTargetConfig>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = RollbackTargetRequest::new().set_validate_only(true);Sourcepub fn set_override_deploy_policy<T, V>(self, v: T) -> Self
pub fn set_override_deploy_policy<T, V>(self, v: T) -> Self
Sets the value of override_deploy_policy.
Example
let x = RollbackTargetRequest::new().set_override_deploy_policy(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for RollbackTargetRequest
impl Clone for RollbackTargetRequest
Sourcefn clone(&self) -> RollbackTargetRequest
fn clone(&self) -> RollbackTargetRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RollbackTargetRequest
impl Debug for RollbackTargetRequest
Sourceimpl Default for RollbackTargetRequest
impl Default for RollbackTargetRequest
Sourcefn default() -> RollbackTargetRequest
fn default() -> RollbackTargetRequest
Sourceimpl Message for RollbackTargetRequest
impl Message for RollbackTargetRequest
Sourceimpl PartialEq for RollbackTargetRequest
impl PartialEq for RollbackTargetRequest
impl StructuralPartialEq for RollbackTargetRequest