#[non_exhaustive]pub struct Rollout {Show 23 fields
pub name: String,
pub uid: String,
pub description: String,
pub annotations: HashMap<String, String>,
pub labels: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub approve_time: Option<Timestamp>,
pub enqueue_time: Option<Timestamp>,
pub deploy_start_time: Option<Timestamp>,
pub deploy_end_time: Option<Timestamp>,
pub target_id: String,
pub approval_state: ApprovalState,
pub state: State,
pub failure_reason: String,
pub deploying_build: String,
pub etag: String,
pub deploy_failure_cause: FailureCause,
pub phases: Vec<Phase>,
pub metadata: Option<Metadata>,
pub controller_rollout: String,
pub rollback_of_rollout: String,
pub rolled_back_by_rollouts: Vec<String>,
pub active_repair_automation_run: String,
/* private fields */
}Expand description
A Rollout resource in the Cloud Deploy API.
A Rollout contains information around a specific deployment to a Target.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Name of the Rollout. Format is
projects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}.
The rollout component must match [a-z]([a-z0-9-]{0,61}[a-z0-9])?
uid: StringOutput only. Unique identifier of the Rollout.
description: StringOptional. Description of the Rollout for user purposes. Max length is 255
characters.
annotations: HashMap<String, String>Optional. User annotations. These attributes can only be set and used by the user, and not by Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations.
labels: HashMap<String, String>Labels are attributes that can be set and used by both the user and by Cloud Deploy. Labels must meet the following constraints:
- Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes.
- All characters must use UTF-8 encoding, and international characters are allowed.
- Keys must start with a lowercase letter or international character.
- Each resource is limited to a maximum of 64 labels.
Both keys and values are additionally constrained to be <= 128 bytes.
create_time: Option<Timestamp>Output only. Time at which the Rollout was created.
approve_time: Option<Timestamp>Output only. Time at which the Rollout was approved.
enqueue_time: Option<Timestamp>Output only. Time at which the Rollout was enqueued.
deploy_start_time: Option<Timestamp>Output only. Time at which the Rollout started deploying.
deploy_end_time: Option<Timestamp>Output only. Time at which the Rollout finished deploying.
target_id: StringRequired. The ID of Target to which this Rollout is deploying.
approval_state: ApprovalStateOutput only. Approval state of the Rollout.
state: StateOutput only. Current state of the Rollout.
failure_reason: StringOutput only. Additional information about the rollout failure, if available.
deploying_build: StringOutput only. The resource name of the Cloud Build Build object that is
used to deploy the Rollout. Format is
projects/{project}/locations/{location}/builds/{build}.
etag: StringThis checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
deploy_failure_cause: FailureCauseOutput only. The reason this rollout failed. This will always be unspecified while the rollout is in progress.
phases: Vec<Phase>Output only. The phases that represent the workflows of this Rollout.
metadata: Option<Metadata>Output only. Metadata contains information about the rollout.
controller_rollout: StringOutput only. Name of the ControllerRollout. Format is
projects/{project}/locations/{location}/deliveryPipelines/{deliveryPipeline}/releases/{release}/rollouts/{rollout}.
rollback_of_rollout: StringOutput only. Name of the Rollout that is rolled back by this Rollout.
Empty if this Rollout wasn’t created as a rollback.
rolled_back_by_rollouts: Vec<String>Output only. Names of Rollouts that rolled back this Rollout.
active_repair_automation_run: StringOutput only. The AutomationRun actively repairing the rollout.
Implementations
Sourceimpl Rollout
impl Rollout
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = Rollout::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Rollout::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_approve_time<T>(self, v: T) -> Self
pub fn set_approve_time<T>(self, v: T) -> Self
Sets the value of approve_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_approve_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_approve_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_approve_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of approve_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_or_clear_approve_time(Some(Timestamp::default()/* use setters */));
let x = Rollout::new().set_or_clear_approve_time(None::<Timestamp>);Sourcepub fn set_enqueue_time<T>(self, v: T) -> Self
pub fn set_enqueue_time<T>(self, v: T) -> Self
Sets the value of enqueue_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_enqueue_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_enqueue_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enqueue_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of enqueue_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_or_clear_enqueue_time(Some(Timestamp::default()/* use setters */));
let x = Rollout::new().set_or_clear_enqueue_time(None::<Timestamp>);Sourcepub fn set_deploy_start_time<T>(self, v: T) -> Self
pub fn set_deploy_start_time<T>(self, v: T) -> Self
Sets the value of deploy_start_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_deploy_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_deploy_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deploy_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of deploy_start_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_or_clear_deploy_start_time(Some(Timestamp::default()/* use setters */));
let x = Rollout::new().set_or_clear_deploy_start_time(None::<Timestamp>);Sourcepub fn set_deploy_end_time<T>(self, v: T) -> Self
pub fn set_deploy_end_time<T>(self, v: T) -> Self
Sets the value of deploy_end_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_deploy_end_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_deploy_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_deploy_end_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of deploy_end_time.
Example
use wkt::Timestamp;
let x = Rollout::new().set_or_clear_deploy_end_time(Some(Timestamp::default()/* use setters */));
let x = Rollout::new().set_or_clear_deploy_end_time(None::<Timestamp>);Sourcepub fn set_target_id<T: Into<String>>(self, v: T) -> Self
pub fn set_target_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_approval_state<T: Into<ApprovalState>>(self, v: T) -> Self
pub fn set_approval_state<T: Into<ApprovalState>>(self, v: T) -> Self
Sets the value of approval_state.
Example
use google_cloud_deploy_v1::model::rollout::ApprovalState;
let x0 = Rollout::new().set_approval_state(ApprovalState::NeedsApproval);
let x1 = Rollout::new().set_approval_state(ApprovalState::DoesNotNeedApproval);
let x2 = Rollout::new().set_approval_state(ApprovalState::Approved);Sourcepub fn set_failure_reason<T: Into<String>>(self, v: T) -> Self
pub fn set_failure_reason<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_deploying_build<T: Into<String>>(self, v: T) -> Self
pub fn set_deploying_build<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_deploy_failure_cause<T: Into<FailureCause>>(self, v: T) -> Self
pub fn set_deploy_failure_cause<T: Into<FailureCause>>(self, v: T) -> Self
Sets the value of deploy_failure_cause.
Example
use google_cloud_deploy_v1::model::rollout::FailureCause;
let x0 = Rollout::new().set_deploy_failure_cause(FailureCause::CloudBuildUnavailable);
let x1 = Rollout::new().set_deploy_failure_cause(FailureCause::ExecutionFailed);
let x2 = Rollout::new().set_deploy_failure_cause(FailureCause::DeadlineExceeded);Sourcepub fn set_phases<T, V>(self, v: T) -> Self
pub fn set_phases<T, V>(self, v: T) -> Self
Sourcepub fn set_metadata<T>(self, v: T) -> Self
pub fn set_metadata<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Self
Sourcepub fn set_controller_rollout<T: Into<String>>(self, v: T) -> Self
pub fn set_controller_rollout<T: Into<String>>(self, v: T) -> Self
Sets the value of controller_rollout.
Example
let x = Rollout::new().set_controller_rollout("example");Sourcepub fn set_rollback_of_rollout<T: Into<String>>(self, v: T) -> Self
pub fn set_rollback_of_rollout<T: Into<String>>(self, v: T) -> Self
Sets the value of rollback_of_rollout.
Example
let x = Rollout::new().set_rollback_of_rollout("example");Sourcepub fn set_rolled_back_by_rollouts<T, V>(self, v: T) -> Self
pub fn set_rolled_back_by_rollouts<T, V>(self, v: T) -> Self
Sets the value of rolled_back_by_rollouts.
Example
let x = Rollout::new().set_rolled_back_by_rollouts(["a", "b", "c"]);Sourcepub fn set_active_repair_automation_run<T: Into<String>>(self, v: T) -> Self
pub fn set_active_repair_automation_run<T: Into<String>>(self, v: T) -> Self
Sets the value of active_repair_automation_run.
Example
let x = Rollout::new().set_active_repair_automation_run("example");Trait Implementations
impl StructuralPartialEq for Rollout