#[non_exhaustive]pub struct SkaffoldModules {
pub configs: Vec<String>,
pub source: Option<Source>,
/* private fields */
}Expand description
Skaffold Config modules and their remote source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.configs: Vec<String>Optional. The Skaffold Config modules to use from the specified source.
source: Option<Source>The source that contains the Skaffold Config modules.
Implementations
Sourceimpl SkaffoldModules
impl SkaffoldModules
Sourcepub fn set_configs<T, V>(self, v: T) -> Self
pub fn set_configs<T, V>(self, v: T) -> Self
Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
use google_cloud_deploy_v1::model::skaffold_modules::SkaffoldGitSource;
let x = SkaffoldModules::new().set_source(Some(
google_cloud_deploy_v1::model::skaffold_modules::Source::Git(SkaffoldGitSource::default().into())));Sourcepub fn git(&self) -> Option<&Box<SkaffoldGitSource>>
pub fn git(&self) -> Option<&Box<SkaffoldGitSource>>
The value of source
if it holds a Git, None if the field is not set or
holds a different branch.
Sourcepub fn set_git<T: Into<Box<SkaffoldGitSource>>>(self, v: T) -> Self
pub fn set_git<T: Into<Box<SkaffoldGitSource>>>(self, v: T) -> Self
Sets the value of source
to hold a Git.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::skaffold_modules::SkaffoldGitSource;
let x = SkaffoldModules::new().set_git(SkaffoldGitSource::default()/* use setters */);
assert!(x.git().is_some());
assert!(x.google_cloud_storage().is_none());
assert!(x.google_cloud_build_repo().is_none());Sourcepub fn google_cloud_storage(&self) -> Option<&Box<SkaffoldGCSSource>>
pub fn google_cloud_storage(&self) -> Option<&Box<SkaffoldGCSSource>>
The value of source
if it holds a GoogleCloudStorage, None if the field is not set or
holds a different branch.
Sourcepub fn set_google_cloud_storage<T: Into<Box<SkaffoldGCSSource>>>(
self,
v: T,
) -> Self
pub fn set_google_cloud_storage<T: Into<Box<SkaffoldGCSSource>>>( self, v: T, ) -> Self
Sets the value of source
to hold a GoogleCloudStorage.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::skaffold_modules::SkaffoldGCSSource;
let x = SkaffoldModules::new().set_google_cloud_storage(SkaffoldGCSSource::default()/* use setters */);
assert!(x.google_cloud_storage().is_some());
assert!(x.git().is_none());
assert!(x.google_cloud_build_repo().is_none());Sourcepub fn google_cloud_build_repo(&self) -> Option<&Box<SkaffoldGCBRepoSource>>
pub fn google_cloud_build_repo(&self) -> Option<&Box<SkaffoldGCBRepoSource>>
The value of source
if it holds a GoogleCloudBuildRepo, None if the field is not set or
holds a different branch.
Sourcepub fn set_google_cloud_build_repo<T: Into<Box<SkaffoldGCBRepoSource>>>(
self,
v: T,
) -> Self
pub fn set_google_cloud_build_repo<T: Into<Box<SkaffoldGCBRepoSource>>>( self, v: T, ) -> Self
Sets the value of source
to hold a GoogleCloudBuildRepo.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_deploy_v1::model::skaffold_modules::SkaffoldGCBRepoSource;
let x = SkaffoldModules::new().set_google_cloud_build_repo(SkaffoldGCBRepoSource::default()/* use setters */);
assert!(x.google_cloud_build_repo().is_some());
assert!(x.git().is_none());
assert!(x.google_cloud_storage().is_none());Trait Implementations
Sourceimpl Clone for SkaffoldModules
impl Clone for SkaffoldModules
Sourcefn clone(&self) -> SkaffoldModules
fn clone(&self) -> SkaffoldModules
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SkaffoldModules
impl Debug for SkaffoldModules
Sourceimpl Default for SkaffoldModules
impl Default for SkaffoldModules
Sourcefn default() -> SkaffoldModules
fn default() -> SkaffoldModules
Sourceimpl Message for SkaffoldModules
impl Message for SkaffoldModules
Sourceimpl PartialEq for SkaffoldModules
impl PartialEq for SkaffoldModules
impl StructuralPartialEq for SkaffoldModules